# bridgestan.py - The Python interface to BridgeStan

[View the Python interface documentation online](https://roualdes.github.io/bridgestan/latest/languages/python.html)

## Installation

**From PyPI**:
```shell
pip install bridgestan
```

**From the downloaded repository**:
Assuming you have already cloned https://github.com/roualdes/bridgestan
```shell
cd python/ # this directory
pip install -e .
```
